@@ -30,15 +30,19 @@ class TestCase(C.TestCaseWithWorkdir):
         """
         return getattr(self.mod, fun)
 
-    def test_10__parse_and_save_show_configs_single_input(self):
+    def test_10_parse_and_save_show_configs__single_input(self):
         # Find test target function lazily.
         tfn = self._fun("parse_and_save_show_configs")
 
         outdir = os.path.join(self.workdir, "out")
         for src in self.sources:
             res = tfn([src], outdir)
+
             self.assertTrue(res)
 
+            self.assertTrue(os.path.exists(res[0][0]))  # output filepath
+            self.assertTrue(res[0][1])  # parsed result (mapping object)
+
             for fname in (P.METADATA_FILENAME, P.ALL_FILENAME):
                 files = glob.glob(os.path.join(outdir, '*', fname))
                 self.assertTrue(files)
@@ -50,6 +54,10 @@ class TestCase(C.TestCaseWithWorkdir):
         res = tfn(self.sources, outdir)
         self.assertTrue(res)
 
+        for opath, cnf in res:
+            self.assertTrue(os.path.exists(opath))
+            self.assertTrue(cnf)
+
         for fname in (P.METADATA_FILENAME, P.ALL_FILENAME):
             files = glob.glob(os.path.join(outdir, '*', fname))
             self.assertTrue(files)
@@ -142,7 +150,7 @@ class TestCase(C.TestCaseWithWorkdir):
 
         for idx, cpath in enumerate(self.cpaths):
             outdir = os.path.join(self.workdir, "out-{!s}".format(idx))
-            res = tfn1([cpath], outdir)
+            res = tfn1([cpath], outdir=outdir)
             self.assertTrue(res)
 
             files = glob.glob(os.path.join(outdir, '*',
@@ -169,7 +177,7 @@ class TestCase(C.TestCaseWithWorkdir):
         tfn3 = self._fun("search_firewall_policy_table_by_addr")
 
         outdir = os.path.join(self.workdir, "out")
-        res = tfn1(self.cpaths, outdir)
+        res = tfn1(self.cpaths, outdir=outdir)
         self.assertTrue(res)
 
         files = sorted(glob.glob(os.path.join(outdir, '*',
