@@ -5,6 +5,8 @@
 # pylint: disable=missing-docstring,invalid-name
 from __future__ import absolute_import
 
+import os.path
+
 import fortios_xutils.firewall as TT
 import fortios_xutils.parser as P
 import tests.common as C
@@ -21,11 +23,10 @@ class TestCases_10(C.TestCase):
         self.assertFalse(rdf.empty)
         self.assertEqual(rdf.to_dict(orient="record"), [dict(a=1)])
 
-    def test_30_guess_filetype(self):
-        self.assertEqual(TT.guess_filetype("foo.pickle"), "pickle")
-        self.assertEqual(TT.guess_filetype("foo.json"), "json")
-        self.assertEqual(TT.guess_filetype("foo.json.gz", compression=True),
-                         "json")
+    def test_30_guess_file_type(self):
+        self.assertEqual(TT.guess_file_type("foo.pickle"), "pickle")
+        self.assertEqual(TT.guess_file_type("foo.json"), "json")
+        self.assertEqual(TT.guess_file_type("foo.json.gz"), "json")
 
 
 class TestCases_20(C.TestCaseWithWorkdir):
@@ -37,7 +38,7 @@ class TestCases_20(C.TestCaseWithWorkdir):
             rdf = TT.pandas_load(filepath)
             self.assertTrue(rdf.empty)
 
-            TT.pandas_save(TT.DF_ZERO, filepath + ".gz", compression="gzip")
+            TT.pandas_save(TT.DF_ZERO, filepath + ".gz")
             self.assertTrue(TT.os.path.exists(filepath + ".gz"))
 
     def test_12_pandas_save_load__excs(self):
@@ -61,6 +62,19 @@ class TestCases_30(C.TestCaseWithWorkdir, TestCasesWithConfigs):
             self.assertFalse(rdf.empty)
             self.assertTrue(TT.os.path.exists(opath))
 
+    def test_30_make_and_save_firewall_policy_tables(self):
+        res = TT.make_and_save_firewall_policy_tables(self.cpaths)
+        self.assertTrue(res)
+        self.assertFalse(any(rdf.empty for rdf in res))
+
+    def test_32_make_and_save_firewall_policy_tables(self):
+        outdir = os.path.join(self.workdir, "out")
+        res = TT.make_and_save_firewall_policy_tables(self.cpaths,
+                                                      outname="fw.pickle.gz",
+                                                      outdir=outdir)
+        self.assertTrue(res)
+        self.assertFalse(any(rdf.empty for rdf in res))
+
 
 class TestCases_40(TestCasesWithConfigs):
 
